import { Component, Directive, HostBinding, Input, NgModule } from "@angular/core";
import { IgxButtonModule } from "../directives/button/button.directive";
var NEXT_ID = 0;
/**
 * IgxCardHeader is container for the card header
 */
var IgxCardHeaderDirective = /** @class */ (function () {
    function IgxCardHeaderDirective() {
    }
    IgxCardHeaderDirective.decorators = [
        { type: Directive, args: [{
                    // tslint:disable-next-line:directive-selector
                    selector: "igx-card-header"
                },] },
    ];
    return IgxCardHeaderDirective;
}());
export { IgxCardHeaderDirective };
/**
 * IgxCardContent is container for the card content
 */
var IgxCardContentDirective = /** @class */ (function () {
    function IgxCardContentDirective() {
    }
    IgxCardContentDirective.decorators = [
        { type: Directive, args: [{
                    // tslint:disable-next-line:directive-selector
                    selector: "igx-card-content"
                },] },
    ];
    return IgxCardContentDirective;
}());
export { IgxCardContentDirective };
/**
 * IgxCardActions is container for the card actions
 */
var IgxCardActionsDirective = /** @class */ (function () {
    function IgxCardActionsDirective() {
    }
    IgxCardActionsDirective.decorators = [
        { type: Directive, args: [{
                    // tslint:disable-next-line:directive-selector
                    selector: "igx-card-actions"
                },] },
    ];
    return IgxCardActionsDirective;
}());
export { IgxCardActionsDirective };
/**
 * IgxCardFooter is container for the card footer
 */
var IgxCardFooterDirective = /** @class */ (function () {
    function IgxCardFooterDirective() {
        this.role = "footer";
    }
    IgxCardFooterDirective.decorators = [
        { type: Directive, args: [{
                    /*     host: {
                                role: "footer"
                            }, */
                    // tslint:disable-next-line:directive-selector
                    selector: "igx-card-footer"
                },] },
    ];
    /** @nocollapse */
    IgxCardFooterDirective.propDecorators = {
        "role": [{ type: Input },],
    };
    return IgxCardFooterDirective;
}());
export { IgxCardFooterDirective };
/**
 * **Ignite UI for Angular Card** -
 * [Documentation](https://www.infragistics.com/products/ignite-ui-angular/angular/components/card.html)
 *
 * The Ignite UI Card serves as a container that allows custom content to be organized in an appealing way.  There are
 * four sections in a card that you can use to organize your content.  These are header, footer, content & actions.
 *
 * Example:
 * ```html
 * <igx-card>
 *   <igx-card-header>
 *     <div>
 *       <h3 class="igx-card-header__title--small">{{title}}</h3>
 *       <h5 class="igx-card-header__subtitle">{{subtitle}}</h5>
 *     </div>
 *   </igx-card-header>
 *   <igx-card-actions>
 *     <div>
 *       <button igxButton igxRipple>Share</button>
 *       <button igxButton igxRipple>Play Album</button>
 *     </div>
 *   </igx-card-actions>
 * </igx-card>
 * ```
 */
var IgxCardComponent = /** @class */ (function () {
    function IgxCardComponent() {
        this.id = "igx-card-" + NEXT_ID++;
    }
    IgxCardComponent.decorators = [
        { type: Component, args: [{
                    selector: "igx-card",
                    template: "<div class=\"igx-card\" role=\"group\">     <ng-content></ng-content> </div>"
                },] },
    ];
    /** @nocollapse */
    IgxCardComponent.propDecorators = {
        "id": [{ type: HostBinding, args: ["attr.id",] }, { type: Input },],
    };
    return IgxCardComponent;
}());
export { IgxCardComponent };
var IgxCardModule = /** @class */ (function () {
    function IgxCardModule() {
    }
    IgxCardModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxCardComponent, IgxCardHeaderDirective,
                        IgxCardContentDirective, IgxCardActionsDirective, IgxCardFooterDirective],
                    exports: [IgxCardComponent, IgxCardHeaderDirective,
                        IgxCardContentDirective, IgxCardActionsDirective, IgxCardFooterDirective],
                    imports: [IgxButtonModule]
                },] },
    ];
    return IgxCardModule;
}());
export { IgxCardModule };
//# sourceMappingURL=card.component.js.map