import { CommonModule } from "@angular/common";
import { Component, EventEmitter, HostBinding, Input, NgModule, Output } from "@angular/core";
import { IgxIconModule } from "../icon";
var NEXT_ID = 0;
export var Direction;
(function (Direction) {
    Direction[Direction["NONE"] = 0] = "NONE";
    Direction[Direction["NEXT"] = 1] = "NEXT";
    Direction[Direction["PREV"] = 2] = "PREV";
})(Direction || (Direction = {}));
/**
 * **Ignite UI for Angular Carousel** -
 * [Documentation](https://www.infragistics.com/products/ignite-ui-angular/angular/components/carousel.html)
 *
 * The Ignite UI Carousel is used to browse or navigate through a collection of slides. Slides can contain custom
 * content such as images or cards and be used for things such as on-boarding tutorials or page-based interfaces.
 * It can be used as a separate fullscreen element or inside another component.
 *
 * Example:
 * ```html
 * <igx-carousel>
 *   <igx-slide>
 *     <h3>First Slide Header</h3>
 *     <p>First slide Content</p>
 *   <igx-slide>
 *   <igx-slide>
 *     <h3>Second Slide Header</h3>
 *     <p>Second Slide Content</p>
 * </igx-carousel>
 * ```
 */
var IgxCarouselComponent = /** @class */ (function () {
    function IgxCarouselComponent() {
        this.role = "region";
        this.id = "igx-carousel-" + NEXT_ID++;
        /**
             * Sets whether the carousel should loop back to the first slide
             * after reaching the last slide.
             *
             * Default value is true
             *
             * @type {boolean}
             * @memberOf IgxCarouselComponent
             */
        this.loop = true;
        /**
             * Sets whether the carousel can pause the slide transitions.
             *
             * Default value is true
             *
             * @type {boolean}
             * @memberOf IgxCarouselComponent
             */
        this.pause = true;
        /**
             * Controls whether the carousel should render the left/right navigation buttons.
             *
             * Default value is true
             *
             * @type {boolean}
             * @memberOf IgxCarouselComponent
             */
        this.navigation = true;
        /**
             * An event that is emitted after a slide transition has happened.
             * Provides a reference to the IgxCarouselComponent as an event argument.
             *
             * @type {EventEmitter}
             * @memberOf IgxCarouselComponent
             */
        this.onSlideChanged = new EventEmitter();
        /**
             * An event that is emitted after a slide has been added to the carousel.
             * Provides a reference to the IgxCarousel as an event argument.
             *
             * @type {EventEmitter}
             * @memberOf IgxCarouselComponent
             */
        this.onSlideAdded = new EventEmitter();
        /**
             * An event that is emitted after a slide has been removed from the carousel.
             * Provides a reference to the IgxCarouselComponent as an event argument.
             *
             * @type {EventEmitter}
             * @memberOf IgxCarouselComponent
             */
        this.onSlideRemoved = new EventEmitter();
        /**
             * An event that is emitted after the carousel has been paused.
             * Provides a reference to the IgxCarousel as an event argument.
             *
             * @type {EventEmitter}
             * @memberOf IgxCarouselComponent
             */
        this.onCarouselPaused = new EventEmitter();
        /**
             * An event that is emitted after the carousel has resumed transitioning between slides.
             * Provides a reference to the IgxCarousel as an event argument.
             *
             * @type {EventEmitter}
             * @memberOf IgxCarouselComponent
             */
        this.onCarouselPlaying = new EventEmitter();
        /**
             * The collection of slides currently in the carousel
             *
             * @type {Array<Slide>}
             * @memberOf IgxCarouselComponent
             */
        this.slides = [];
        this._total = 0;
    }
    Object.defineProperty(IgxCarouselComponent.prototype, "interval", {
        get: function () {
            return this._interval;
        },
        set: function (value) {
            this._interval = +value;
            this._restartInterval();
        },
        enumerable: true,
        configurable: true
    });
    IgxCarouselComponent.prototype.ngOnDestroy = function () {
        this._destroyed = true;
        if (this._lastInterval) {
            clearInterval(this._lastInterval);
        }
    };
    IgxCarouselComponent.prototype.setAriaLabel = function (slide) {
        return "Item " + (slide.index + 1) + " of " + this.total;
    };
    Object.defineProperty(IgxCarouselComponent.prototype, "total", {
        /**
         * The total number of slides in the carousel.
         *
         * @readonly
         * @type {number}
         * @memberOf IgxCarouselComponent
         */
        get: /**
             * The total number of slides in the carousel.
             *
             * @readonly
             * @type {number}
             * @memberOf IgxCarouselComponent
             */
        function () {
            return this._total;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCarouselComponent.prototype, "current", {
        /**
         * The index of the slide being currently shown.
         *
         * @readonly
         * @type {number}
         * @memberOf IgxCarouselComponent
         */
        get: /**
             * The index of the slide being currently shown.
             *
             * @readonly
             * @type {number}
             * @memberOf IgxCarouselComponent
             */
        function () {
            return !this._currentSlide ? 0 : this._currentSlide.index;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCarouselComponent.prototype, "isPlaying", {
        /**
         * Returns the state of the carousel - paused or playing.
         *
         * @readonly
         * @type {boolean}
         * @memberOf IgxCarouselComponent
         */
        get: /**
             * Returns the state of the carousel - paused or playing.
             *
             * @readonly
             * @type {boolean}
             * @memberOf IgxCarouselComponent
             */
        function () {
            return this._playing;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCarouselComponent.prototype, "isDestroyed", {
        /**
         * Whether the carousel is destroyed, i.e. `ngOnDestroy` has been called.
         *
         * @readonly
         * @type {boolean}
         * @memberOf IgxCarouselComponent
         */
        get: /**
             * Whether the carousel is destroyed, i.e. `ngOnDestroy` has been called.
             *
             * @readonly
             * @type {boolean}
             * @memberOf IgxCarouselComponent
             */
        function () {
            return this._destroyed;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Returns the slide corresponding to the provided index or null.
     *
     * @param {number} index
     * @returns {IgxSlideComponent}
     *
     * @memberOf IgxCarouselComponent
     */
    /**
         * Returns the slide corresponding to the provided index or null.
         *
         * @param {number} index
         * @returns {IgxSlideComponent}
         *
         * @memberOf IgxCarouselComponent
         */
    IgxCarouselComponent.prototype.get = /**
         * Returns the slide corresponding to the provided index or null.
         *
         * @param {number} index
         * @returns {IgxSlideComponent}
         *
         * @memberOf IgxCarouselComponent
         */
    function (index) {
        for (var _i = 0, _a = this.slides; _i < _a.length; _i++) {
            var each = _a[_i];
            if (each.index === index) {
                return each;
            }
        }
    };
    /**
     * Adds a new slide to the carousel.
     *
     * @param {IgxSlideComponent} slide
     *
     * @memberOf IgxCarouselComponent
     */
    /**
         * Adds a new slide to the carousel.
         *
         * @param {IgxSlideComponent} slide
         *
         * @memberOf IgxCarouselComponent
         */
    IgxCarouselComponent.prototype.add = /**
         * Adds a new slide to the carousel.
         *
         * @param {IgxSlideComponent} slide
         *
         * @memberOf IgxCarouselComponent
         */
    function (slide) {
        slide.index = this.total;
        this.slides.push(slide);
        this._total += 1;
        if (this.total === 1 || slide.active) {
            this.select(slide);
            if (this.total === 1) {
                this.play();
            }
        }
        else {
            slide.active = false;
        }
        this.onSlideAdded.emit({ carousel: this, slide: slide });
    };
    /**
     * Removes the given slide from the carousel.
     *
     * @param {IgxSlideComponent} slide
     * @returns
     *
     * @memberOf IgxCarouselComponent
     */
    /**
         * Removes the given slide from the carousel.
         *
         * @param {IgxSlideComponent} slide
         * @returns
         *
         * @memberOf IgxCarouselComponent
         */
    IgxCarouselComponent.prototype.remove = /**
         * Removes the given slide from the carousel.
         *
         * @param {IgxSlideComponent} slide
         * @returns
         *
         * @memberOf IgxCarouselComponent
         */
    function (slide) {
        this.slides.splice(slide.index, 1);
        this._total -= 1;
        if (!this.total) {
            this._currentSlide = null;
            return;
        }
        for (var i = 0; i < this.total; i++) {
            this.slides[i].index = i;
        }
        this.onSlideRemoved.emit({ carousel: this, slide: slide });
    };
    /**
     * Kicks in a transition for a given slide with a given direction.
     *
     * @param {IgxSlideComponent} slide
     * @param {Direction} [direction=Direction.NONE]
     *
     * @memberOf IgxCarouselComponent
     */
    /**
         * Kicks in a transition for a given slide with a given direction.
         *
         * @param {IgxSlideComponent} slide
         * @param {Direction} [direction=Direction.NONE]
         *
         * @memberOf IgxCarouselComponent
         */
    IgxCarouselComponent.prototype.select = /**
         * Kicks in a transition for a given slide with a given direction.
         *
         * @param {IgxSlideComponent} slide
         * @param {Direction} [direction=Direction.NONE]
         *
         * @memberOf IgxCarouselComponent
         */
    function (slide, direction) {
        if (direction === void 0) { direction = Direction.NONE; }
        var newIndex = slide.index;
        if (direction === Direction.NONE) {
            direction = newIndex > this.current ? Direction.NEXT : Direction.PREV;
        }
        if (slide && slide !== this._currentSlide) {
            this._moveTo(slide, direction);
        }
    };
    /**
     * Transitions to the next slide in the carousel.
     *
     * @returns
     *
     * @memberOf IgxCarouselComponent
     */
    /**
         * Transitions to the next slide in the carousel.
         *
         * @returns
         *
         * @memberOf IgxCarouselComponent
         */
    IgxCarouselComponent.prototype.next = /**
         * Transitions to the next slide in the carousel.
         *
         * @returns
         *
         * @memberOf IgxCarouselComponent
         */
    function () {
        var index = (this.current + 1) % this.total;
        if (index === 0 && !this.loop) {
            this.stop();
            return;
        }
        return this.select(this.get(index), Direction.NEXT);
    };
    /**
     * Transitions to the previous slide in the carousel.
     *
     * @returns
     *
     * @memberOf IgxCarouselComponent
     */
    /**
         * Transitions to the previous slide in the carousel.
         *
         * @returns
         *
         * @memberOf IgxCarouselComponent
         */
    IgxCarouselComponent.prototype.prev = /**
         * Transitions to the previous slide in the carousel.
         *
         * @returns
         *
         * @memberOf IgxCarouselComponent
         */
    function () {
        var index = this.current - 1 < 0 ?
            this.total - 1 : this.current - 1;
        if (!this.loop && index === this.total - 1) {
            this.stop();
            return;
        }
        return this.select(this.get(index), Direction.PREV);
    };
    /**
     * Resumes playing of the carousel if in paused state.
     * No-op otherwise.
     *
     *
     * @memberOf IgxCarouselComponent
     */
    /**
         * Resumes playing of the carousel if in paused state.
         * No-op otherwise.
         *
         *
         * @memberOf IgxCarouselComponent
         */
    IgxCarouselComponent.prototype.play = /**
         * Resumes playing of the carousel if in paused state.
         * No-op otherwise.
         *
         *
         * @memberOf IgxCarouselComponent
         */
    function () {
        if (!this._playing) {
            this._playing = true;
            this.onCarouselPlaying.emit(this);
            this._restartInterval();
        }
    };
    /**
     * Stops slide transitions if the `pause` options is set to `true`.
     * No-op otherwise.
     *
     *
     * @memberOf IgxCarouselComponent
     */
    /**
         * Stops slide transitions if the `pause` options is set to `true`.
         * No-op otherwise.
         *
         *
         * @memberOf IgxCarouselComponent
         */
    IgxCarouselComponent.prototype.stop = /**
         * Stops slide transitions if the `pause` options is set to `true`.
         * No-op otherwise.
         *
         *
         * @memberOf IgxCarouselComponent
         */
    function () {
        if (this.pause) {
            this._playing = false;
            this.onCarouselPaused.emit(this);
            this._resetInterval();
        }
    };
    IgxCarouselComponent.prototype.onKeydown = function (event) {
        switch (event.key) {
            case "ArrowLeft":
                this.prev();
                break;
            case "ArrowRight":
                this.next();
                break;
            default:
                return;
        }
    };
    IgxCarouselComponent.prototype._moveTo = function (slide, direction) {
        if (this._destroyed) {
            return;
        }
        slide.direction = direction;
        slide.active = true;
        if (this._currentSlide) {
            this._currentSlide.direction = direction;
            this._currentSlide.active = false;
        }
        this._currentSlide = slide;
        this.onSlideChanged.emit({ carousel: this, slide: slide });
        this._restartInterval();
    };
    IgxCarouselComponent.prototype._resetInterval = function () {
        if (this._lastInterval) {
            clearInterval(this._lastInterval);
            this._lastInterval = null;
        }
    };
    IgxCarouselComponent.prototype._restartInterval = function () {
        var _this = this;
        this._resetInterval();
        if (!isNaN(this.interval) && this.interval > 0) {
            this._lastInterval = setInterval(function () {
                var tick = +_this.interval;
                if (_this._playing && _this.total && !isNaN(tick) && tick > 0) {
                    _this.next();
                }
                else {
                    _this.stop();
                }
            }, this.interval);
        }
    };
    IgxCarouselComponent.decorators = [
        { type: Component, args: [{
                    selector: "igx-carousel",
                    template: "<div tabindex=\"0\" aria-label=\"carousel\" class=\"igx-carousel\"         (mouseenter)=\"stop()\"         (mouseleave)=\"play()\"         (swipeleft)=\"next()\"         (swiperight)=\"prev()\"         (keydown)=\"onKeydown($event)\"         (tap)=\"isPlaying ? stop() : play()\">     <ul class=\"igx-carousel__indicators\" [hidden]=\"slides.length <= 1\">         <li *ngFor=\"let slide of slides\" [attr.aria-label]=\"setAriaLabel(slide)\" [attr.aria-selected]=\"slide.active\" [class.active]=\"slide.active === true\"             (click)=\"select(slide)\"></li>     </ul>     <div class=\"igx-carousel__inner\" role=\"list\">         <ng-content></ng-content>     </div>     <div *ngIf=\"navigation\">         <a role=\"button\" tabindex=\"0\" class=\"igx-carousel__arrow--prev\" (click)=\"prev()\" [hidden]=\"!slides.length\">             <igx-icon fontSet=\"material\" name=\"arrow_back\"></igx-icon>         </a>         <a role=\"button\" tabindex=\"0\" class=\"igx-carousel__arrow--next\" (click)=\"next()\" [hidden]=\"!slides.length\">             <igx-icon fontSet=\"material\" name=\"arrow_forward\"></igx-icon>         </a>     </div> </div>"
                },] },
    ];
    /** @nocollapse */
    IgxCarouselComponent.propDecorators = {
        "role": [{ type: HostBinding, args: ["attr.role",] },],
        "id": [{ type: HostBinding, args: ["attr.id",] }, { type: Input },],
        "loop": [{ type: Input },],
        "pause": [{ type: Input },],
        "interval": [{ type: Input },],
        "navigation": [{ type: Input },],
        "onSlideChanged": [{ type: Output },],
        "onSlideAdded": [{ type: Output },],
        "onSlideRemoved": [{ type: Output },],
        "onCarouselPaused": [{ type: Output },],
        "onCarouselPlaying": [{ type: Output },],
    };
    return IgxCarouselComponent;
}());
export { IgxCarouselComponent };
/**
 * A slide component that usually holds an image and/or a caption text.
 * IgxSlideComponent is usually a child component of an IgxCarouselComponent.
 *
 * ```
 * <igx-slide [input bindings] >
 *    <ng-content></ng-content>
 * </igx-slide>
 * ```
 *
 * @export
 * @class IgxSlideComponent
 * @implements {OnInit}
 * @implements {OnDestroy}
 */
var IgxSlideComponent = /** @class */ (function () {
    function IgxSlideComponent(carousel) {
        this.carousel = carousel;
    }
    IgxSlideComponent.prototype.ngOnInit = function () {
        this.carousel.add(this);
    };
    IgxSlideComponent.prototype.ngOnDestroy = function () {
        this.carousel.remove(this);
    };
    IgxSlideComponent.decorators = [
        { type: Component, args: [{
                    selector: "igx-slide",
                    template: "<div     role=\"listitem\"     [class.active]=\"active\"     class=\"igx-slide\"     [attr.aria-selected]=\"active\"     [attr.aria-live]=\"active ? 'polite' : null\"     [attr.tabIndex]=\"active ? 0 : null\" >     <ng-content></ng-content> </div>"
                },] },
    ];
    /** @nocollapse */
    IgxSlideComponent.ctorParameters = function () { return [
        { type: IgxCarouselComponent, },
    ]; };
    IgxSlideComponent.propDecorators = {
        "index": [{ type: Input },],
        "direction": [{ type: Input },],
        "active": [{ type: HostBinding, args: ["class.active",] }, { type: Input },],
    };
    return IgxSlideComponent;
}());
export { IgxSlideComponent };
var IgxCarouselModule = /** @class */ (function () {
    function IgxCarouselModule() {
    }
    IgxCarouselModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxCarouselComponent, IgxSlideComponent],
                    exports: [IgxCarouselComponent, IgxSlideComponent],
                    imports: [CommonModule, IgxIconModule]
                },] },
    ];
    return IgxCarouselModule;
}());
export { IgxCarouselModule };
//# sourceMappingURL=carousel.component.js.map