import { Directive, HostListener, Input, NgModule } from "@angular/core";
import { IgxNavigationService } from "./nav.service";
/**
 * Directive that can toggle targets through provided NavigationService.
 *
 * Usage:
 * ```
 * <button igxNavToggle="ID"> Toggle </button>
 * ```
 * Where the `ID` matches the ID of compatible `IToggleView` component.
 */
var IgxNavigationToggleDirective = /** @class */ (function () {
    function IgxNavigationToggleDirective(nav) {
        this.state = nav;
    }
    IgxNavigationToggleDirective.prototype.toggleNavigationDrawer = function () {
        this.state.toggle(this.target, true);
    };
    IgxNavigationToggleDirective.decorators = [
        { type: Directive, args: [{ selector: "[igxNavToggle]" },] },
    ];
    /** @nocollapse */
    IgxNavigationToggleDirective.ctorParameters = function () { return [
        { type: IgxNavigationService, },
    ]; };
    IgxNavigationToggleDirective.propDecorators = {
        "target": [{ type: Input, args: ["igxNavToggle",] },],
        "toggleNavigationDrawer": [{ type: HostListener, args: ["click",] },],
    };
    return IgxNavigationToggleDirective;
}());
export { IgxNavigationToggleDirective };
/**
 * Directive that can close targets through provided NavigationService.
 *
 * Usage:
 * ```
 * <button igxNavClose="ID"> Close </button>
 * ```
 * Where the `ID` matches the ID of compatible `IToggleView` component.
 */
var IgxNavigationCloseDirective = /** @class */ (function () {
    function IgxNavigationCloseDirective(nav) {
        this.state = nav;
    }
    IgxNavigationCloseDirective.prototype.closeNavigationDrawer = function () {
        this.state.close(this.target, true);
    };
    IgxNavigationCloseDirective.decorators = [
        { type: Directive, args: [{ selector: "[igxNavClose]" },] },
    ];
    /** @nocollapse */
    IgxNavigationCloseDirective.ctorParameters = function () { return [
        { type: IgxNavigationService, },
    ]; };
    IgxNavigationCloseDirective.propDecorators = {
        "target": [{ type: Input, args: ["igxNavClose",] },],
        "closeNavigationDrawer": [{ type: HostListener, args: ["click",] },],
    };
    return IgxNavigationCloseDirective;
}());
export { IgxNavigationCloseDirective };
var IgxNavigationModule = /** @class */ (function () {
    function IgxNavigationModule() {
    }
    IgxNavigationModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxNavigationCloseDirective, IgxNavigationToggleDirective],
                    exports: [IgxNavigationCloseDirective, IgxNavigationToggleDirective],
                    providers: [IgxNavigationService]
                },] },
    ];
    return IgxNavigationModule;
}());
export { IgxNavigationModule };
//# sourceMappingURL=directives.js.map