import { CommonModule } from "@angular/common";
import { Directive, ElementRef, EventEmitter, Input, NgModule, Output, Pipe, Renderer2 } from "@angular/core";
var IgxFilterDirective = /** @class */ (function () {
    function IgxFilterDirective(element, renderer) {
        this.element = element;
        this.filtering = new EventEmitter(false);
        this.filtered = new EventEmitter();
    }
    IgxFilterDirective.prototype.ngOnChanges = function (changes) {
        // Detect only changes of input value
        if (changes.filterOptions &&
            changes.filterOptions.currentValue &&
            changes.filterOptions.currentValue.inputValue !== undefined &&
            changes.filterOptions.previousValue &&
            changes.filterOptions.currentValue.inputValue !== changes.filterOptions.previousValue.inputValue) {
            this.filter();
        }
    };
    IgxFilterDirective.prototype.filter = function () {
        if (!this.filterOptions.items) {
            return;
        }
        var args = { cancel: false, items: this.filterOptions.items };
        this.filtering.emit(args);
        if (args.cancel) {
            return;
        }
        var pipe = new IgxFilterPipe();
        var filtered = pipe.transform(this.filterOptions.items, this.filterOptions);
        this.filtered.emit({ filteredItems: filtered });
    };
    IgxFilterDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[igxFilter]"
                },] },
    ];
    /** @nocollapse */
    IgxFilterDirective.ctorParameters = function () { return [
        { type: ElementRef, },
        { type: Renderer2, },
    ]; };
    IgxFilterDirective.propDecorators = {
        "filtering": [{ type: Output },],
        "filtered": [{ type: Output },],
        "filterOptions": [{ type: Input, args: ["igxFilter",] },],
    };
    return IgxFilterDirective;
}());
export { IgxFilterDirective };
var IgxFilterPipe = /** @class */ (function () {
    function IgxFilterPipe() {
    }
    IgxFilterPipe.prototype.transform = function (items, 
    // options - initial settings of filter functionality
    // options - initial settings of filter functionality
    options) {
        var result = [];
        if (!items || !items.length || !options) {
            return;
        }
        if (options.items) {
            items = options.items;
        }
        result = items.filter(function (item) {
            var match = options.matchFn(options.formatter(options.get_value(item, options.key)), options.inputValue);
            if (match) {
                if (options.metConditionFn) {
                    options.metConditionFn(item);
                }
            }
            else {
                if (options.overdueConditionFn) {
                    options.overdueConditionFn(item);
                }
            }
            return match;
        });
        return result;
    };
    IgxFilterPipe.decorators = [
        { type: Pipe, args: [{
                    name: "igxFilter",
                    pure: false
                },] },
    ];
    return IgxFilterPipe;
}());
export { IgxFilterPipe };
var IgxFilterOptions = /** @class */ (function () {
    function IgxFilterOptions() {
        // Input text value that will be used as a filtering pattern (matching condition is based on it)
        this.inputValue = "";
    }
    // Function - get value to be tested from the item
    // item - single item of the list to be filtered
    // key - property name of item, which value should be tested
    // Default behavior - returns "key"- named property value of item if key si provided,
    // otherwise textContent of the item's html element
    // Function - get value to be tested from the item
    // item - single item of the list to be filtered
    // key - property name of item, which value should be tested
    // Default behavior - returns "key"- named property value of item if key si provided,
    // otherwise textContent of the item's html element
    IgxFilterOptions.prototype.get_value = 
    // Function - get value to be tested from the item
    // item - single item of the list to be filtered
    // key - property name of item, which value should be tested
    // Default behavior - returns "key"- named property value of item if key si provided,
    // otherwise textContent of the item's html element
    function (item, key) {
        var result = "";
        if (key) {
            result = item[key].toString();
        }
        else if (item.element) {
            if (item.element.nativeElement) {
                result = item.element.nativeElement.textContent.trim();
                // Check if element doesn't return the DOM element directly
            }
            else if (item.element.textContent) {
                result = item.element.textContent.trim();
            }
        }
        return result;
    };
    // Function - formats the original text before matching process
    // Default behavior - returns text to lower case
    // Function - formats the original text before matching process
    // Default behavior - returns text to lower case
    IgxFilterOptions.prototype.formatter = 
    // Function - formats the original text before matching process
    // Default behavior - returns text to lower case
    function (valueToTest) {
        return valueToTest.toLowerCase();
    };
    // Function - determines whether the item met the condition
    // valueToTest - text value that should be tested
    // inputValue - text value from input that condition is based on
    // Default behavior - "contains"
    // Function - determines whether the item met the condition
    // valueToTest - text value that should be tested
    // inputValue - text value from input that condition is based on
    // Default behavior - "contains"
    IgxFilterOptions.prototype.matchFn = 
    // Function - determines whether the item met the condition
    // valueToTest - text value that should be tested
    // inputValue - text value from input that condition is based on
    // Default behavior - "contains"
    function (valueToTest, inputValue) {
        return valueToTest.indexOf(inputValue && inputValue.toLowerCase() || "") > -1;
    };
    // Function - executed after matching test for every matched item
    // Default behavior - shows the item
    // Function - executed after matching test for every matched item
    // Default behavior - shows the item
    IgxFilterOptions.prototype.metConditionFn = 
    // Function - executed after matching test for every matched item
    // Default behavior - shows the item
    function (item) {
        if (item.hasOwnProperty("hidden")) {
            item.hidden = false;
        }
    };
    // Function - executed for every NOT matched item after matching test
    // Default behavior - hides the item
    // Function - executed for every NOT matched item after matching test
    // Default behavior - hides the item
    IgxFilterOptions.prototype.overdueConditionFn = 
    // Function - executed for every NOT matched item after matching test
    // Default behavior - hides the item
    function (item) {
        if (item.hasOwnProperty("hidden")) {
            item.hidden = true;
        }
    };
    return IgxFilterOptions;
}());
export { IgxFilterOptions };
var IgxFilterModule = /** @class */ (function () {
    function IgxFilterModule() {
    }
    IgxFilterModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxFilterDirective, IgxFilterPipe],
                    exports: [IgxFilterDirective, IgxFilterPipe],
                    imports: [CommonModule]
                },] },
    ];
    return IgxFilterModule;
}());
export { IgxFilterModule };
//# sourceMappingURL=filter.directive.js.map