import { Pipe } from "@angular/core";
import { cloneArray } from "../core/utils";
import { DataUtil } from "../data-operations/data-util";
import { IgxGridAPIService } from "./api.service";
var IgxGridSortingPipe = /** @class */ (function () {
    function IgxGridSortingPipe(gridAPI) {
        this.gridAPI = gridAPI;
    }
    IgxGridSortingPipe.prototype.transform = function (collection, expressions, id, pipeTrigger) {
        var state = { expressions: [] };
        state.expressions = this.gridAPI.get(id).sortingExpressions;
        if (!state.expressions.length) {
            return collection;
        }
        return DataUtil.sort(cloneArray(collection), state);
    };
    IgxGridSortingPipe.decorators = [
        { type: Pipe, args: [{
                    name: "gridSort",
                    pure: true
                },] },
    ];
    /** @nocollapse */
    IgxGridSortingPipe.ctorParameters = function () { return [
        { type: IgxGridAPIService, },
    ]; };
    return IgxGridSortingPipe;
}());
export { IgxGridSortingPipe };
var IgxGridPagingPipe = /** @class */ (function () {
    function IgxGridPagingPipe(gridAPI) {
        this.gridAPI = gridAPI;
    }
    IgxGridPagingPipe.prototype.transform = function (collection, page, perPage, id, pipeTrigger) {
        if (page === void 0) { page = 0; }
        if (perPage === void 0) { perPage = 15; }
        if (!this.gridAPI.get(id).paging) {
            return collection;
        }
        var state = {
            index: page,
            recordsPerPage: perPage
        };
        var result = DataUtil.page(cloneArray(collection), state);
        this.gridAPI.get(id).pagingState = state;
        return result;
    };
    IgxGridPagingPipe.decorators = [
        { type: Pipe, args: [{
                    name: "gridPaging",
                    pure: true
                },] },
    ];
    /** @nocollapse */
    IgxGridPagingPipe.ctorParameters = function () { return [
        { type: IgxGridAPIService, },
    ]; };
    return IgxGridPagingPipe;
}());
export { IgxGridPagingPipe };
var IgxGridFilteringPipe = /** @class */ (function () {
    function IgxGridFilteringPipe(gridAPI) {
        this.gridAPI = gridAPI;
    }
    IgxGridFilteringPipe.prototype.transform = function (collection, expressions, logic, id, pipeTrigger) {
        var state = { expressions: [], logic: logic };
        state.expressions = this.gridAPI.get(id).filteringExpressions;
        if (!state.expressions.length) {
            return collection;
        }
        var result = DataUtil.filter(cloneArray(collection), state);
        this.gridAPI.get(id).filteredData = result;
        return result;
    };
    IgxGridFilteringPipe.decorators = [
        { type: Pipe, args: [{
                    name: "gridFiltering",
                    pure: true
                },] },
    ];
    /** @nocollapse */
    IgxGridFilteringPipe.ctorParameters = function () { return [
        { type: IgxGridAPIService, },
    ]; };
    return IgxGridFilteringPipe;
}());
export { IgxGridFilteringPipe };
var IgxGridFilterConditionPipe = /** @class */ (function () {
    function IgxGridFilterConditionPipe() {
    }
    IgxGridFilterConditionPipe.prototype.transform = function (value) {
        return value.split(/(?=[A-Z])/).join(" ");
    };
    IgxGridFilterConditionPipe.decorators = [
        { type: Pipe, args: [{
                    name: "filterCondition",
                    pure: true
                },] },
    ];
    return IgxGridFilterConditionPipe;
}());
export { IgxGridFilterConditionPipe };
//# sourceMappingURL=grid.pipes.js.map