import { AfterContentInit, ElementRef, EventEmitter, OnChanges, OnDestroy, OnInit, Renderer, SimpleChange, TemplateRef } from "@angular/core";
import "rxjs/add/observable/fromEvent";
import "rxjs/add/observable/interval";
import "rxjs/add/operator/debounce";
import { IgxNavigationService, IToggleView } from "../core/navigation";
import { HammerGesturesManager } from "../core/touch";
import { IgxNavDrawerMiniTemplateDirective, IgxNavDrawerTemplateDirective } from "./navigation-drawer.directives";
export declare class IgxNavigationDrawerComponent implements IToggleView, OnInit, AfterContentInit, OnDestroy, OnChanges {
    private elementRef;
    private _state;
    protected renderer: Renderer;
    private _touchManager;
    cssClass: string;
    /** ID of the component */
    id: string;
    /**
     * Position of the Navigation Drawer. Can be "left"(default) or "right". Only has effect when not pinned.
     */
    position: string;
    /**
     * Enables the use of touch gestures to manipulate the drawer - such as swipe/pan from edge to open,
     * swipe toggle and pan drag.
     */
    enableGestures: boolean;
    /** State of the drawer. */
    isOpen: boolean;
    /** When pinned the drawer is relatively positioned instead of sitting above content. May require additional layout styling. */
    pin: boolean;
    /**
     * Minimum device width required for automatic pin to be toggled.
     * Default is 1024, can be set to a falsy value to disable this behavior.
     */
    pinThreshold: number;
    /**
     * Returns nativeElement of the component.
     */
    readonly element: any;
    /**
     * Width of the drawer in its open state. Defaults to "280px".
     */
    width: string;
    /**
     * Width of the drawer in its mini state. Defaults to 60px.
     */
    miniWidth: string;
    /** Pinned state change output for two-way binding  */
    pinChange: EventEmitter<boolean>;
    /** Event fired as the Navigation Drawer is about to open. */
    opening: EventEmitter<{}>;
    /** Event fired when the Navigation Drawer has opened. */
    opened: EventEmitter<{}>;
    /** Event fired as the Navigation Drawer is about to close. */
    closing: EventEmitter<{}>;
    /** Event fired when the Navigation Drawer has closed. */
    closed: EventEmitter<{}>;
    readonly template: TemplateRef<any>;
    private _miniTemplate;
    miniTemplate: IgxNavDrawerMiniTemplateDirective;
    protected contentTemplate: IgxNavDrawerTemplateDirective;
    readonly flexWidth: string;
    private _gesturesAttached;
    private _widthCache;
    private _resizeObserver;
    private css;
    private _drawer;
    private _overlay;
    private _styleDummy;
    readonly drawer: any;
    readonly overlay: any;
    readonly styleDummy: any;
    /** Pan animation properties */
    private _panning;
    private _panStartWidth;
    private _panLimit;
    private _previousDeltaX;
    /**
     * Property to decide whether to change width or translate the drawer from pan gesture.
     */
    readonly hasAnimateWidth: boolean;
    private _maxEdgeZone;
    /**
     * Used for touch gestures (swipe and pan).
     * Defaults to 50 (in px) and is extended to at least 110% of the mini template width if available.
     * @protected set method
     */
    readonly maxEdgeZone: number;
    /**
     * Get the Drawer width for specific state. Will attempt to evaluate requested state and cache.
     */
    readonly expectedWidth: number;
    /**
     * Get the Drawer mini width for specific state. Will attempt to evaluate requested state and cache.
     */
    readonly expectedMiniWidth: number;
    readonly touchManager: HammerGesturesManager;
    /**
     * Exposes optional navigation service
     */
    readonly state: IgxNavigationService;
    constructor(elementRef: ElementRef, _state: IgxNavigationService, renderer: Renderer, _touchManager: HammerGesturesManager);
    ngOnInit(): void;
    ngAfterContentInit(): void;
    ngOnDestroy(): void;
    ngOnChanges(changes: {
        [propName: string]: SimpleChange;
    }): void;
    /**
     * Toggle the open state of the Navigation Drawer.
     * @param fireEvents Optional flag determining whether events should be fired or not.
     */
    toggle(fireEvents?: boolean): void;
    /**
     * Open the Navigation Drawer. Has no effect if already opened.
     * @param fireEvents Optional flag determining whether events should be fired or not.
     */
    open(fireEvents?: boolean): void;
    /**
     * Close the Navigation Drawer. Has no effect if already closed.
     * @param fireEvents Optional flag determining whether events should be fired or not.
     */
    close(fireEvents?: boolean): void;
    protected set_maxEdgeZone(value: number): void;
    protected ensureDrawerHeight(): void;
    /**
     * Get the Drawer width for specific state. Will attempt to evaluate requested state and cache.
     * @param mini Request mini width instead
     */
    protected getExpectedWidth(mini?: boolean): number;
    private getWindowWidth();
    /**
     * Sets the drawer width.
     * @param width Width to set, must be valid CSS size string.
     */
    private setDrawerWidth(width);
    /**
     * Get current Drawer width.
     */
    private getDrawerWidth();
    private ensureEvents();
    private updateEdgeZone();
    private checkPinThreshold;
    private swipe;
    private panstart;
    private pan;
    private panEnd;
    private resetPan();
    /**
     * Sets the absolute position or width in case the drawer doesn't change position.
     * @param x the number pixels to translate on the X axis or the width to set. 0 width will clear the style instead.
     * @param opacity optional value to apply to the overlay
     */
    private setXSize(x, opacity?);
    private toggleOpenedEvent;
    private toggleClosedEvent;
}
