import { AfterViewInit, EventEmitter, OnInit, Renderer2 } from "@angular/core";
import { ControlValueAccessor } from "@angular/forms";
export declare enum SliderType {
    /**
     * Slider with single thumb.
     */
    SLIDER = 0,
    /**
     *  Range slider with multiple thumbs, that can mark the range.
     */
    RANGE = 1,
}
export interface IRangeSliderValue {
    lower: number;
    upper: number;
}
export interface ISliderValueChangeEventArgs {
    oldValue: number | IRangeSliderValue;
    value: number | IRangeSliderValue;
}
export declare class IgxSliderComponent implements ControlValueAccessor, OnInit, AfterViewInit {
    private renderer;
    /** ID of the component */
    id: string;
    /**
     * Disables or enables UI interaction.
     */
    disabled: boolean;
    /**
     * Marks slider as continuous. By default is considered that the slider is discrete.
     * Discrete slider does not have ticks and does not shows bubble labels for values.
     */
    isContinuous: boolean;
    /**
     * The type of the slider. The slider can be SliderType.SLIDER or SliderType.RANGE
     * @type {SliderType}
     */
    type: SliderType;
    /***
     * The duration visibility of thumbs labels. The default value is 750 milliseconds.
     * @type {number}
     */
    thumbLabelVisibilityDuration: number;
    /**
     * The incremental/decremental step of the value when dragging the thumb.
     * The default step is 1, and step should not be less or equal than 0.
     * @type {number}
     */
    step: number;
    /**
     * This event is emitted when user has stopped interacting the thumb and value is changed.
     * @type {EventEmitter}
     */
    onValueChange: EventEmitter<ISliderValueChangeEventArgs>;
    isActiveLabel: boolean;
    private activeHandle;
    private slider;
    private track;
    private ticks;
    private thumbFrom;
    private thumbTo;
    private _minValue;
    private width;
    private xOffset;
    private xPointer;
    private pPointer;
    private pMin;
    private pMax;
    private hasViewInit;
    private timer;
    private _maxValue;
    private _lowerBound?;
    private _upperBound?;
    private _lowerValue;
    private _upperValue;
    private _onChangeCallback;
    private _onTouchedCallback;
    constructor(renderer: Renderer2);
    readonly isRange: boolean;
    /**
     * Gets the minimal value for the slider.
     * @returns {number}
     */
    /**
     * Sets the minimal value for the slider.
     * The default minimal value is 0.
     * @type {number}
     */
    minValue: number;
    /**
     * Gets the minimal value for the slider
     * @returns {number}
     */
    /**
     * Sets the maximal value for the slider
     * @type {number}
     */
    maxValue: number;
    /**
     * Gets the lower bound of the slider.
     * @returns {number}
     */
    /**
     * Sets the lower boundary of the slider value.
     * If not set is the same as min value.
     * @type {number}
     */
    lowerBound: number;
    /**
     * Gets the upper bound of the slider.
     * @returns {number}
     */
    /**
     * Sets the upper bound of the slider value.
     * If not set is the same as max value.
     * @type {number}
     */
    upperBound: number;
    lowerValue: number;
    upperValue: number;
    /**
     * Returns the slider value. If the slider is of type SLIDER the returned value is number.
     * If the slider type is RANGE the returned value is object containing lower and upper properties for the values.
     * @returns {any}
     */
    /**
     * Sets the slider value.
     * If the slider is of type SLIDER the argument is number. By default if no value is set the default value is
     * same as lower upper bound.
     * If the slider type is RANGE the the argument is object containing lower and upper properties for the values.
     * By default if no value is set the default value is for lower value it is the same as lower bound and if no
     * value is set for the upper value it is the same as the upper bound.
     * @param value
     */
    value: number | IRangeSliderValue;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    writeValue(value: any): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    showThumbsLabels(): void;
    onFocus($event: FocusEvent): void;
    onPanEnd($event: any): void;
    hideThumbLabelsOnBlur(): void;
    onKeyDown($event: KeyboardEvent): boolean;
    onTap($event: any): void;
    update($event: any): void;
    hideThumbsLabels(): void;
    private generateTickMarks(color, interval);
    private toggleThumbLabel();
    private getSliderOffset();
    private toFixed(num);
    private positionHandle(handle, position);
    private positionHandlesAndUpdateTrack();
    private closestHandle();
    private setTickInterval();
    private snapValueToStep(value);
    private closestTo(goal, positions);
    private setValues();
    private setSliderWidth();
    private setPointerPosition(e);
    private setSliderOffset();
    private setPointerPercent();
    private valueToFraction(value);
    private fractionToValue(fraction);
    private fractionToPercent(fraction);
    private limit(num);
    private updateTrack();
    private hasValueChanged(oldValue);
    private emitValueChanged(oldValue);
}
export declare class IgxSliderModule {
}
